; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;--- None of your own command definitions should be above this line. ---

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = x+y
time = 1

;-| Special Motions |--------------------------------------------------------
;
[Command]
name = "JumpFor"
command = ~D, U, F
time = 30

[Command]
name = "JumpFor2"
command = ~D, F, U, F
time = 30

[Command]
name = "JumpBak"
command = ~D, U, B
time = 30

[Command]
name = "JumpBak2"
command = ~D, B, U, B
time = 30

[Command]
name = "JumpUP"
command = ~D, U, U
time = 30

[Command]
name = "MoveF"
command = /a
time = 2

[Command]
name = "MoveB"
command = /b
time = 2

[Command]
name = "TurnA"
command = x
time = 1

[Command]
name = "WarpA"
command = x
time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b
;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "SupahJump"
;command = ~$D, $U
command = ~$D, $U
time = 5
buffer.time = 2

[Command]
name = "ChargedSupahJump"
;command = ~$D, $U
command = ~12$D, $U
time = 5
buffer.time = 2

[Command]
name = "upper_what"
command = ~15$D, $U, x
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, y
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, z
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, a
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, b
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, c
time = 10


;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; nor encounters any VarSets within State -1.
; But they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

[State -1, AI Reset]
type = VarSet
trigger1 = random<100;1;var(55)=0
trigger2 = var(52) = 300
trigger3 = var(55) = 0
var(52) = 0
ignorehitpause = 1


[State -1, AI Reset]
type = VarSet
trigger1 = 1
var(53) = 0
ignorehitpause = 1

; AI-related stuff starts here

[State -1, Cycle]
type = VarSet
triggerall = var(55)
trigger1 = (gametime%90)=0
var(51) = random%3;random%5
ignorehitpause = 1
[State -1, Cycle]
type = VarSet
triggerall = var(55)
trigger1 = var(51) = 2
trigger1 = backedgedist < -160
var(51) = 1
ignorehitpause = 1
;[State -1, Cycle]
;type = VarSet
;triggerall = var(55)
;trigger1 = inguarddist || (p2dist x = [-144,119])
;trigger1 = p2movetype = A
;trigger1 = random < 100
;var(51) = ifelse(random<500,0,2)
;ignorehitpause = 1


[State -1, Reverse]
type = VarSet
triggerall = var(55)
;triggerall = random < 500
triggerall = random < var(55)*2
trigger1 = p2bodydist x < 60
trigger2 = frontedgedist < 80
var(52) = 202
ignorehitpause = 1

[State -1, Accelerate]
type = VarSet
triggerall = var(55)
;triggerall = random < 500
triggerall = random < var(55)*2
trigger1 = p2dist x > 300
trigger2 = backedgedist < 60
var(52) = 201
ignorehitpause = 1

[State -1, RAM IT UP]
type = VarSet
triggerall = var(55)
triggerall = random < var(55)*2
;triggerall = random < 500
triggerall = numenemy
trigger1 = p2dist x < -80
trigger2 = backedgedist < 80
trigger3 = frontedgedist < 48
trigger4 = enemynear,backedgebodydist <= 40
trigger5 = random < var(55)
var(52) = 450
ignorehitpause = 1

[State -1, HE HURT ME WHAT DO I DO]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0
triggerall = random < var(55)*2
triggerall = numenemy
triggerall = numhelper(211)
trigger1 = helper(211),gethitvar(damage)
var(52) = ifelse(random<100,450,201+random%2)
ignorehitpause = 1

[State -1, ROAR]
type = VarSet
triggerall = roundstate = 2
triggerall = var(55)
triggerall = random < var(55)*var(55)*var(55)
triggerall = numhelper(610)
triggerall = helper(610),var(40) <= 0
triggerall = numenemy
trigger1 = helper(600),var(0)<6
trigger1 = p2stateno = [5100,5150]
var(53) = var(53) | floor(exp(0*ln(2)) + 0.5)
ignorehitpause = 1

[State -1, FIRE]
type = VarSet
triggerall = roundstate = 2
triggerall = var(55)
triggerall = random < var(55)*var(55)*var(55)
triggerall = numhelper(610)
triggerall = numhelper(600)
triggerall = numenemy
trigger1 = helper(600),var(0)<6
trigger1 = ( helper(600),p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= 24
trigger1 = helper(610),var(40) <= 0
trigger1 = (helper(600),p2dist x > -15) || (stateno = 450)
trigger2 = helper(600),var(0)>=6
trigger2 = helper(600),var(40)<=0
trigger2 = p2bodydist x = [-18,110]
var(53) = var(53) | floor(exp(1*ln(2)) + 0.5)
ignorehitpause = 1

[State -1, MISSILE]
type = VarSet
triggerall = roundstate = 2
triggerall = var(55)
triggerall = random < var(55)*var(55)*var(55)
triggerall = numhelper(200)
triggerall = numhelper(600)
triggerall = numenemy
trigger1 = helper(200),var(0)<2
trigger2 = helper(200),var(0)>=2
trigger2 = helper(600),var(40)<=0
trigger2 = p2bodydist x = [-68,80]
var(53) = var(53) | floor(exp(2*ln(2)) + 0.5)
ignorehitpause = 1

[State -1, LASER]
type = VarSet
triggerall = roundstate = 2
triggerall = var(55)
triggerall = random < var(55)*var(55)*var(55)
triggerall = numhelper(610)
triggerall = helper(610),var(40) <= 0
triggerall = numenemy
trigger1 = p2dist x != [-68,-30]
var(53) = var(53) | floor(exp(3*ln(2)) + 0.5)
ignorehitpause = 1

; AI-related stuff ends here


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`

;[State -1, Jump Up]
;type = ChangeState
;value = 100
;triggerall = (var(55)<5 && (command = "JumpUP")) || var(52) = 100
;triggerall = !numhelper(3200)
;trigger1 = statetype != A
;trigger1 = ctrl

[State -1, STOP]
type = VarSet
triggerall = ctrl || roundstate > 2
trigger1 = stateno != 450
trigger1 = stateno != 181
fvar(15) = 0
ignorehitpause = 1

[State -1, accelerate]
type = VarSet
triggerall = ctrl; || roundstate > 2
triggerall = numhelper(202)
triggerall = helper(202), stateno = 202
trigger1 = var(55) < 5
trigger1 = command = "MoveF"
trigger2 = var(52) = 201 || var(52) = 211
fvar(15) = 1
ignorehitpause = 1

[State -1, decelerate]
type = VarSet
triggerall = ctrl; || roundstate > 2
triggerall = numhelper(202)
triggerall = helper(202), stateno = 202
trigger1 = var(55) < 5
trigger1 = command = "MoveB"
trigger2 = var(52) = 202 || var(52) = 212
fvar(15) = -1
ignorehitpause = 1

[State -1, STOP]
type = VarSet
triggerall = ctrl || roundstate > 2
triggerall = stateno != 450
triggerall = stateno != 181
trigger1 = fvar(15) = 0
trigger2 = fvar(15) > 0
trigger2 = fvar(14) < 0
trigger3 = fvar(15) < 0
trigger3 = fvar(14) > 0
fvar(14) = ifelse(abs(fvar(14))<=0.4,0,fvar(14)*0.75)
ignorehitpause = 1

[State -1, accelerate]
type = VarSet
triggerall = ctrl; || roundstate > 2
triggerall = numhelper(202)
triggerall = helper(202), stateno = 202
;trigger1 = var(55) < 5
;trigger1 = command = "MoveF"
;trigger2 = var(52) = 201 || var(52) = 211
trigger1 = fvar(15) > 0
fvar(14) = ifelse(fvar(14)+0.2>=4.4,4.4,fvar(14)+0.2);5
ignorehitpause = 1

[State -1, decelerate]
type = VarSet
triggerall = ctrl; || roundstate > 2
triggerall = numhelper(202)
triggerall = helper(202), stateno = 202
;trigger1 = var(55) < 5
;trigger1 = command = "MoveB"
;trigger2 = var(52) = 202 || var(52) = 212
trigger1 = fvar(15) < 0
fvar(14) = ifelse(fvar(14)-0.18<=-3.6,-3.6,fvar(14)-0.18);-5
ignorehitpause = 1

;[State -1, handbrake]
;type = VelSet
;triggerall = ctrl || roundstate > 2
;triggerall = abs(vel x)<0.5
;trigger1 = var(18) = 1
;x = 0
;ignorehitpause = 1

[State -1, apply velocity]
type = VelSet
trigger1 = roundstate >= 2;ctrl || roundstate > 2
x = fvar(14)
ignorehitpause = 1

[State -1, flag taunt]
type = VarSet
triggerall = roundstate = 2
triggerall = ctrl || stateno = 450
;triggerall = frontedgedist <= -170 || backedgedist <= -170
triggerall = alive
triggerall = numhelper(610)
triggerall = helper(610),var(40) <= 0
trigger1 = command = "start"
;trigger2 = var(52) = 195
trigger2 = (var(53) & floor(exp(0*ln(2)) + 0.5))
var(40) = var(40) | floor(exp(0*ln(2)) + 0.5)
ignorehitpause = 1
[State -1, unflag taunt]
type = VarSet
trigger1 = numhelper(610)
trigger1 = helper(610),stateno = 612
trigger1 = (var(40) & floor(exp(0*ln(2)) + 0.5))
var(40) = var(40) ^ floor(exp(0*ln(2)) + 0.5)
ignorehitpause = 1

[State -1, flag firestream]
type = VarSet
triggerall = roundstate = 2
triggerall = ctrl || stateno = 450
;triggerall = frontedgedist <= -170 || backedgedist <= -170
triggerall = alive
triggerall = numhelper(610)
triggerall = numhelper(600)
triggerall = (helper(610),var(40) <= 0) || ((helper(610),stateno=299) && (helper(600),var(40)=0) )
triggerall = (helper(600),var(41) != 1) || (helper(600),var(40) = 0)
trigger1 = command = "x"
trigger1 = var(55) < 5
trigger2 = (var(53) & floor(exp(1*ln(2)) + 0.5))
var(40) = var(40) | floor(exp(1*ln(2)) + 0.5)
ignorehitpause = 1
[State -1, unflag firestream]
type = VarSet
triggerall = numhelper(610)
triggerall = numhelper(600)
triggerall = (var(40) & floor(exp(1*ln(2)) + 0.5))
trigger1 = helper(610),stateno = 611
trigger2 = helper(600),var(0)>=6;helper(610),stateno = 299
trigger2 = helper(600),var(40) >= 1
trigger2 = helper(600),var(41) = 0
var(40) = var(40) ^ floor(exp(1*ln(2)) + 0.5)
ignorehitpause = 1

[State -1, flag missiles]
type = VarSet
triggerall = roundstate = 2
triggerall = ctrl || stateno = 450
;triggerall = frontedgedist <= -170 || backedgedist <= -170
triggerall = alive
triggerall = numhelper(600)
triggerall = numhelper(610)
triggerall = numhelper(200)
triggerall = (helper(600),var(40) <= 0) || (helper(200),var(0) < 2)
triggerall = (helper(610),stateno = 299) || (helper(610),stateno = 610) || (helper(200),var(0) < 2)
trigger1 = command = "y"
trigger1 = var(55) < 5
trigger2 = (var(53) & floor(exp(2*ln(2)) + 0.5))
var(40) = var(40) | floor(exp(2*ln(2)) + 0.5)
ignorehitpause = 1
[State -1, unflag missiles]
type = VarSet
triggerall = numhelper(200)
triggerall = (var(40) & floor(exp(2*ln(2)) + 0.5))
trigger1 = helper(200),var(0) < 2
trigger1 = helper(200),var(40) > 0
trigger2 = helper(200),var(0) >= 2
trigger2 = numhelper(600)
trigger2 = helper(600),var(40) > 0
trigger2 = helper(600),var(41) != 0
var(40) = var(40) ^ floor(exp(2*ln(2)) + 0.5)
ignorehitpause = 1

[State -1, flag lasercannon]
type = VarSet
triggerall = roundstate = 2
triggerall = ctrl || stateno = 450
;triggerall = frontedgedist <= -170 || backedgedist <= -170
triggerall = alive
triggerall = numhelper(203)
triggerall = helper(203),var(40) <= 0
trigger1 = command = "z"
;trigger1 = var(55) < 5
trigger2 = (var(53) & floor(exp(3*ln(2)) + 0.5))
var(40) = var(40) | floor(exp(3*ln(2)) + 0.5)
ignorehitpause = 1
[State -1, unflag lasercannon]
type = VarSet
trigger1 = numhelper(203)
trigger1 = helper(203),anim = 231
trigger1 = (var(40) & floor(exp(3*ln(2)) + 0.5))
var(40) = var(40) ^ floor(exp(3*ln(2)) + 0.5)
ignorehitpause = 1

[State -1, ram]
type = ChangeState
triggerall = roundstate = 2
triggerall = ctrl
triggerall = alive
triggerall = numhelper(202)
triggerall = helper(202), stateno = 202
trigger1 = var(55) < 5
trigger1 = command = "c"
trigger2 = var(52) = 450
value = 450
ctrl = 0

;[State -1, turn around]
;type = ChangeState
;triggerall = roundstate = 2
;triggerall = ctrl
;triggerall = frontedgedist <= -170 || backedgedist <= -170
;triggerall = alive
;trigger1 = var(55) < 5
;trigger1 = command = "TurnA"
;trigger2 = var(52) = 300
;value = 5
;ctrl = 0

;[State -1, warp around]
;type = ChangeState
;triggerall = roundstate = 2
;triggerall = ctrl
;triggerall = frontedgedist <= -170 || backedgedist <= -170
;triggerall = alive
;triggerall = numhelper(202)
;triggerall = helper(202), stateno = 202
;trigger1 = var(55) < 5
;trigger1 = command = "WarpA"
;trigger2 = var(52) = 301
;value = 6
;ctrl = 0



